@@ -68,9 +68,8 @@ cwtsquiz <- function(input, noctave, nvoice = 1, w0 = 2*pi,
    Ioutput <- z$Itmp
    dim(Routput) <- c(newsize,pp)
    dim(Ioutput) <- c(newsize,pp)
-   i <- sqrt(as.complex(-1))
    if(twoD) {
-     output <- Routput[1:isize,] + Ioutput[1:isize,] * i
+     output <- Routput[1:isize,] + 1i*Ioutput[1:isize,]
      if(plot){
         image(Mod(output),xlab="Time", ylab="log(scale)")
 	title("Squeezed Wavelet Transform Modulus")
@@ -85,7 +84,7 @@ cwtsquiz <- function(input, noctave, nvoice = 1, w0 = 2*pi,
          Rtmp[,i,j] <- Routput[1:isize,(i-1)*nvoice+j]
          Itmp[,i,j] <- Ioutput[1:isize,(i-1)*nvoice+j]
       }
-     Rtmp + Itmp * i
+     Rtmp + 1i*Itmp
    }
 }
 
