@@ -70,9 +70,8 @@ cwtTh <- function(input, noctave, nvoice = 1, moments,
    Ioutput <- z$Itmp
    dim(Routput) <- c(newsize,pp)
    dim(Ioutput) <- c(newsize,pp)
-   i <- sqrt(as.complex(-1))
    if(twoD) {
-     output <- Routput[1:isize,] + Ioutput[1:isize,] * i
+     output <- Routput[1:isize,] + 1i*Ioutput[1:isize,]
      if(plot) image(Mod(output),xlab="Time",ylab="log(scale)")
      title("Wavelet Transform Modulus")
      output
@@ -85,7 +84,7 @@ cwtTh <- function(input, noctave, nvoice = 1, moments,
          Rtmp[,i,j] <- Routput[1:isize,(i-1)*nvoice+j]
          Itmp[,i,j] <- Ioutput[1:isize,(i-1)*nvoice+j]
       }
-     Rtmp + Itmp * i
+     Rtmp + 1i*Itmp
    }
 }
 
@@ -134,9 +133,7 @@ vwtTh <- function(input, scale, moments)
 
    Routput <- z$Rtmp
    Ioutput <- z$Itmp
-   i <- sqrt(as.complex(-1))
-
-   Routput[1:isize] + Ioutput[1:isize] * i
+   Routput[1:isize] + 1i*Ioutput[1:isize]
 }
 
 
